//---------------------------------------------------------------------------
// Include file used by solitair.pov - Defines wooden solitaire board
// Author: Geoff Goldberg 1993
//---------------------------------------------------------------------------

//-------------------------------------------------------------------
// Solitaire ball that sits in one of the depressions in the platter
//-------------------------------------------------------------------
#declare Ball = 

union
{
	sphere { <0 1.5 0> 1 }
}

//------------------------------------------------------------------------
// Depression that solitaire ball sits in - slightly larger than the ball
//------------------------------------------------------------------------
#declare Depression = 

union
{
	sphere { <0 1.5 0> 1.1 } // Not 1.0 - perfect fit looks unrealistic
}

//--------------------------
// Row of seven depressions
//--------------------------
#declare DepressionRow = 

union
{
	union
	{
		Depression
		translate <-12 0 0>
	}

	union
	{
		Depression
		translate <-8 0 0>
	}

	union
	{
		Depression
		translate <-4 0 0>
	}

	union
	{
		Depression
		translate <0 0 0>
	}

	union
	{
		Depression
		translate <4 0 0>
	}

	union
	{
		Depression
		translate <8 0 0>
	}

	union
	{
		Depression
		translate <12 0 0>
	}
}

//-----------------------------
// Column of seven depressions
//-----------------------------
#declare DepressionCol = 

union
{
 	union { DepressionRow }
	rotate <0 90 0>
}

//----------------------
// Wood solitaire board
//----------------------
#declare Platter = 

difference
{
	union
	{
		//-----------------------------------------------------
		// The platter - Cylinder with y height 1, radius 18
		//-----------------------------------------------------
		intersection 
		{ 
			Disk_Y 
			scale <16 0.5 16>
		}

		//--------------------------------------------------------
		// Rounded edge of platter - Torus: R0 = 16, R1 = 0.5
		//--------------------------------------------------------
		quartic 
		{
	             < 1.0   0.0   0.0   0.0   2.0   0.0   0.0   2.0   0.0       
      		
	       	      -512.5   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0       
      
        	       0.0   0.0   1.0   0.0   0.0   2.0   0.0   511.5   0.0       
      
	       	       0.0   0.0   0.0   1.0   0.0  -512.5   0.0   65408.0625 >
		}

		translate <0 .5 0>
	}

	//--------------------------------------------------------
	// Groove around rim to hold jumped balls
	// Torus: R0 = 15, R1 = 1
	//--------------------------------------------------------
	quartic 
	{
             < 1.0   0.0   0.0   0.0   2.0   0.0   0.0   2.0   0.0       
       	      -452   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0       
       	       0.0   0.0   1.0   0.0   0.0   2.0   0.0   448   0.0       
       	       0.0   0.0   0.0   1.0   0.0  -452   0.0   50176 >

	       translate <0 1.5 0>
	}

	union
	{
		DepressionRow
		translate <0 0 4>
	}

	union
	{
		DepressionRow
		translate <0 0 0>
	}

	union
	{
		DepressionRow
		translate <0 0 -4>
	}

	union
	{
		DepressionCol
		translate <-4 0 0>
	}

	union
	{
		DepressionCol
		translate <0 0 0>
	}

	union
	{
		DepressionCol
		translate <4 0 0>
	}
}


