//---------------------------------------------------------------------------
// Source file for solitair.gif - Marbles on a wooden solitaire board
// Author: Geoff Goldberg 1993
//
// Requires platter.inc and flock.gif
//---------------------------------------------------------------------------
#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "shapes.inc"
#include "platter.inc"

camera
{
   location < 0 7 -29>
   direction <0.0  0.0  1.5>
   up <0.0  1.0  0.0>
   right <1.333333 0.0 0.0>
   look_at <1 0 0>
}

//--------------------------------------------------------------------
// Top light - adds extra highlights to the rim & groove of the board
// (A back light looks great on the wood, but adds an unwanted extra
// highlight to the marbles)
//--------------------------------------------------------------------
object { light_source { <0  100 0> color Gray80 } }

//------------------------------------------------------------------
// Two front lights to eliminate all dark shadows - made them spots
// to keep the background dim
//------------------------------------------------------------------

//----------------------
// Front right spotlight
//----------------------
object
{
	light_source 
	{  
		< 30 40 -50 > color Gray80
             	spotlight
             	point_at <0 0 -5>
             	radius 60
             	falloff 150
             	tightness 30
	}
}

//----------------------
// Front left spotlight
//----------------------
object
{
	light_source 
	{  
		< -30 60 -50 > color Gray80
             	spotlight
             	point_at <0 0 0>
             	radius 45
             	falloff 120
             	tightness 30
	}
}

//----------------
// Cliche floor
//----------------
object 
{
	plane {<0 1 0> 0  }

	texture 
	{
            checker 
	    	color Gray45
		color Gray55

	    scale <8 8 8>
	    reflection 0.5
	    ambient .3
	    rotate <0 45 0>
        }
}

//-----------------------------------------------------------
// Skirting board - A reflective copper skirting board? Hmmm
//-----------------------------------------------------------
object
{
	union
	{
	 	box 	{ <-100 0 50> <100 5 55> }
		quadric	{ Cylinder_X translate <0 5 51> }
	}

	texture
	{
		Copper_Metal
		reflection .45
		ambient 0.3
	}
}

//----------------
// Wall
//----------------
object
{
	plane { <0 0 -1> -51 }

	texture
	{
		Copper_Metal

		//--------------------------------------
		// Emboss effect with Escheresque birds
		//--------------------------------------
		bump_map
		{
			0 gif "flock.gif" interpolate 2 bump_size 3
		}

		scale <4 4 4>
		translate <0 -1.5 0>
		ambient 0.3
	}
}

//----------------
// Ceiling
//----------------
object
{
	plane { <0 -1 0> -100 }

	texture
	{
		color White
		ambient .35
	}
}

//----------------------------
// Solitaire board with balls
//----------------------------
composite
{
	
	object
	{
		difference { Platter }

		texture 
		{ 
			DMFDarkOak
			translate <3 3 0>
			rotate <6 40 0> 
			phong 0.5
			phong_size 200
			reflection 0.22
			ambient .2
		}
	}

	//----------------------------------------------------------
	// Fill some of the board's depressions with marble spheres
	//----------------------------------------------------------
	object
	{
 		union { Ball }
		texture
		{
			Stone1
		}

		translate < 0 0 8 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone2
		}

		translate < -8 0 4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone3
		}

		translate < -4 0 4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone4
		}

		translate < 4 0 4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone5
		}

		translate < 8 0 4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone6
		}

		translate < -12 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone7
		}

		translate < -8 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Mirror
		}

		translate < 0 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone9
		}

		translate < 4 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone10
		}

		translate < 8 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone11
		}

		translate < -4 0 -8 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone12
		}

		translate < -12 0 -4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone13
		}

		translate < 0 0 -8 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone14
		}

		translate < 0 0 -4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone23
		}

		translate < 8 0 -4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone16
		}

		translate < -4 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Glass3
		}

		translate < -4 0 -4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone22
		}

		translate < 4 0 -4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone19
		}

		translate < 4 0 -12 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone20
		}

		translate < 0 0 4 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone21
		}

		translate < 9.1013 0 -11.9234 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone18
		}

		translate < 12 0 0 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Brass_Valley
		}

		translate < 10.6066 0 -10.6066 >
	}

	object
	{
 		union { Ball }
		texture
		{
			Stone24
		}

		translate < 2.6047 0 -14.7721 >
	}

	bounded_by
	{
		box { < -16.5 -2.5 -16.5 > < 16.5 2.5 16.5 > }
	}

	rotate    <0 30 0>
	translate <0  0 2.5>
}
